@@ -73,10 +73,31 @@ class EventPostProcessingRuleAdmin(admin.ModelAdmin):
     list_filter=["is_active","event_class"]
     inlines=[EventPostProcessingREAdmin]
 ##
+##
+##
+class EventCorrelationMatchedClassAdmin(admin.TabularInline):
+    extra=3
+    model=EventCorrelationMatchedClass
+##
+##
+##
+class EventCorrelationMatchedVarAdmin(admin.TabularInline):
+    extra=3
+    model=EventCorrelationMatchedVar
+##
+##
+##
 class EventCorrelationRuleAdmin(admin.ModelAdmin):
-    list_display=["name","is_builtin"]
+    list_display=["name","is_builtin","python_link"]
     search_fields=["name"]
     list_filter=["is_builtin"]
+    inlines=[EventCorrelationMatchedClassAdmin,EventCorrelationMatchedVarAdmin]
+##
+##
+##
+class EventArchivationRuleAdmin(admin.ModelAdmin):
+    list_display=["event_class","ttl","ttl_measure","action"]
+    list_filter=["action"]
 ##
 admin.site.register(MIB, MIBAdmin)
 admin.site.register(MIBData, MIBDataAdmin)
@@ -86,3 +107,4 @@ admin.site.register(EventClass, EventClassAdmin)
 admin.site.register(EventClassificationRule, EventClassificationRuleAdmin)
 admin.site.register(EventPostProcessingRule, EventPostProcessingRuleAdmin)
 admin.site.register(EventCorrelationRule, EventCorrelationRuleAdmin)
+admin.site.register(EventArchivationRule, EventArchivationRuleAdmin)
\ No newline at end of file
