@@ -3,11 +3,14 @@
 ## Copyright (C) 2007-2009 The NOC Project
 ## See LICENSE for details
 ##----------------------------------------------------------------------
-import os,tempfile,sha
-
-def safe_rewrite(path,text):
+import os,tempfile,sha,urllib2
+from noc.lib.version import get_version
+##
+## Create new file filled with "text" safely
+##
+def safe_rewrite(path,text,mode=None):
     d=os.path.dirname(path)
-    if not os.path.exists(d):
+    if d and not os.path.exists(d):
         os.makedirs(d)
     b=os.path.basename(path)
     h,p=tempfile.mkstemp(suffix=".tmp",prefix=b,dir=d)
@@ -18,6 +21,8 @@ def safe_rewrite(path,text):
         os.unlink(path)
     os.link(p,path)
     os.unlink(p)
+    if mode:
+        os.chmod(path,mode)
 ##
 ## Check file content is differ from string
 ##
@@ -89,3 +94,12 @@ class temporary_file(object):
 ##
 def in_dir(file,dir):
     return os.path.commonprefix([dir,os.path.normpath(file)])==dir
+##
+## urlopen wrapper
+##
+def urlopen(url):
+    if url.startswith("http://") or url.startswith("https://"):
+        r=urllib2.Request(url,headers={"User-Agent":"NOC/%s"%get_version()})
+        return urllib2.urlopen(r)
+    else:
+        return urllib2.urlopen(url)
