@@ -60,7 +60,7 @@ class ScriptRegistry(Registry):
     apps=["noc.sa"]
     exclude=["highlight"]
     def register_generics(self):
-        for c in [c for c in self.classes.values() if c.name and c.name.startswith("Generic.") and c.requires]:
+        for c in [c for c in self.classes.values() if c.name and c.name.startswith("Generic.")]:
             g,name=c.name.split(".")
             for p in profile_registry.classes:
                 s_name=p+"."+name
@@ -205,7 +205,7 @@ class Script(threading.Thread):
         data=self.cli_provider.queue.get(block=True)
         if self.strip_echo and data.lstrip().startswith(cmd):
             data=self.strip_first_lines(data.lstrip())
-        self.debug("cli() returns:\n---------\n%s\n---------"%data)
+        self.debug("cli() returns:\n---------\n%s\n---------"%repr(data))
         return data
     ##
     ## Clean up config from all unnecessary trash
@@ -410,6 +410,7 @@ class ScriptSocket(object):pass
 ##
 ##
 class CLITelnetSocket(ScriptSocket,CLI,PTYSocket):
+    TTL=30
     def __init__(self,factory,profile,access_profile):
         logging.debug("CLITelnetSocket connecting '%s'"%access_profile.address)
         cmd_args=["/usr/bin/telnet",access_profile.address]
@@ -422,6 +423,7 @@ class CLITelnetSocket(ScriptSocket,CLI,PTYSocket):
 ##
 ##
 class CLISSHSocket(ScriptSocket,CLI,PTYSocket):
+    TTL=30
     def __init__(self,factory,profile,access_profile):
         logging.debug("CLISSHSocket connecting '%s'"%access_profile.address)
         cmd_args=["/usr/bin/ssh","-o","StrictHostKeyChecking no","-l",access_profile.user]
